@@ -81,7 +81,7 @@ options available.
     deploy_parser.add_argument('--no-push', dest='push', action='store_false',
         default=True, help="Run all the steps except the last push step."
         "Useful for debugging")
-        
+
 
     configure_parser = subcommand.add_parser('configure', help="Configure doctr. This command should be run locally (not on Travis).")
     configure_parser.set_defaults(func=configure)
@@ -233,12 +233,9 @@ def configure(args, parser):
             Be sure to allow write access for the key.
             """.format(ssh_key=ssh_key, deploy_keys_url=deploy_keys_url, N=N)))
 
-        # TODO: Should we just delete the public key?
 
         print(dedent("""\
         {N}. Commit the file {keypath}.enc.
-        The file {keypath}.pub contains the public deploy key for GitHub. It
-        does not need to be committed.
         """.format(keypath=args.key_path, N=N)))
 
     options = ''
@@ -250,10 +247,15 @@ def configure(args, parser):
     print(dedent("""\
     {N}. Add
 
-        - pip install doctr
-        - doctr deploy{options}
+        script:
+          - set -e
+          - # Command to build your docs
+          - pip install doctr
+          - doctr deploy{options}
 
-    to the docs build of your .travis.yml.
+    to the docs build of your .travis.yml.  The 'set -e' prevents doctr from
+    running when the docs build fails. Use the 'script' section so that if
+    doctr fails it causes the build to fail.
     """.format(options=options, N=N)))
 
     print(dedent("""\
